<?php
/**
 * The Swoosh script to delete a gateway.
 *
 * Copyright 2003-2005 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: swoosh/gateways/delete.php,v 1.16 2005/01/03 14:35:32 jan Exp $
 */

@define('SWOOSH_BASE', dirname(__FILE__) . '/..');
require_once SWOOSH_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin()) {
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$vars = &Variables::getDefaultVariables();
$gateway_id = $vars->get('gateway_id');
$form_submit = $vars->get('submitbutton');

/* Get the gateway to be deleted. */
$gateway = $storage->getGateway($gateway_id);
$vars = &new Variables($gateway);

/* Get the form object. */
$form = &Horde_Form::singleton('', $vars, sprintf(_("Delete Gateway '%s'?"), $gateway['gateway_name']));

/* Set up the form. */
$form->setButtons(array(_("Delete"), _("Do not delete")));
$form->addHidden('', 'gateway_id', 'int', false);

if ($form_submit == _("Delete")) {
    $form->validate($vars);

    if ($form->isValid()) {
        /* Delete this gateway. */
        $delete = $storage->deleteGateway($gateway_id);
        if (is_a($delete, 'PEAR_Error')) {
            $notification->push(sprintf(_("Could not delete gateway. %s"), $delete->getMessage()), 'horde.error');
        } else {
            $notification->push(_("Gateway deleted."), 'horde.success');
            $url = Horde::applicationUrl('gateways/index.php', true);
            header('Location: ' . $url);
            exit;
        }
    }
} elseif (!empty($form_submit)) {
    $notification->push(_("Gateway not deleted."), 'horde.message');
    $url = Horde::applicationUrl('gateways/index.php', true);
    header('Location: ' . $url);
    exit;
}

/* Render the form. */
require_once 'Horde/Form/Renderer.php';
$renderer = &new Horde_Form_Renderer();
$main = Util::bufferOutput(array($form, 'renderActive'), $renderer, $vars, 'delete.php', 'post');

/* Set up template fields. */
$swoosh_tpl->set('main', $main);
$swoosh_tpl->set('menu', Swoosh::getMenu('string'));
$swoosh_tpl->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

require SWOOSH_TEMPLATES . '/common-header.inc';
echo $swoosh_tpl->fetch(SWOOSH_TEMPLATES . '/main/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
