<?php
/**
 * The Swoosh script to edit available gateways.
 *
 * Copyright 2003-2005 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: swoosh/gateways/edit.php,v 1.20 2005/01/03 14:35:32 jan Exp $
 */

@define('SWOOSH_BASE', dirname(__FILE__) . '/..');
require_once SWOOSH_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Action.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin()) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$changed_gateway = false;
$vars = &Variables::getDefaultVariables();
$gateway_id = $vars->get('gateway_id');
$old_gateway = $vars->get('old_gateway_driver');
$formname = $vars->get('formname');

/* Check if a gateway is being edited. */
if ($gateway_id && !$formname) {
    $vars = &new Variables($storage->getGateway($gateway_id));
}

/* Get gateway. */
$gateway = $vars->get('gateway_driver');

/* Get list of available gateway drivers. */
$gateways = Net_SMS::getDrivers();

if ($gateway != $old_gateway && $formname) {
    $changed_gateway = true;
    $notification->push(_("Changed gateway driver."), 'horde.message');
}

/* Selected a gateway so get the info and parameters for this gateway. */
if ($gateway) {
    $gateway_info = Net_SMS::getGatewayInfo($gateway);
    $gateway_params = Net_SMS::getGatewayParams($gateway);
    $send_params = Net_SMS::getDefaultSendParams($gateway);
    if ($gateway_id) {
        $title = sprintf(_("Edit '%s' Gateway"), $gateway_info['name']);
    } else {
        $title = sprintf(_("Add '%s' Gateway"), $gateway_info['name']);
    }
} else {
    $title = _("Add Gateway");
}

/* Set up the form object. */
$form = &Horde_Form::singleton('', $vars, $title);

/* Set up the form. */
$form->setButtons(_("Save"), true);
$form->addHidden('', 'gateway_id', 'int', false);
$form->addHidden('', 'old_gateway_driver', 'text', false);
if (!empty($gateway_info['desc'])) {
    $form->addVariable($gateway_info['desc'], 'description', 'description', false);
}
$v = &$form->addVariable(_("Gateway"), 'gateway_driver', 'enum', true, false, null, array($gateways, true));
$action = &Horde_Form_Action::factory('submit');
$v->setAction($action);
$form->addVariable(_("Name"), 'gateway_name', 'text', true, false);

if (!empty($gateway_params)) {
    foreach ($gateway_params as $id => $param) {
        $param['required'] = isset($param['required']) ? $param['required']
                                                       : true;
        $param['readonly'] = isset($param['readonly']) ? $param['readonly']
                                                       : false;
        $param['desc'] = isset($param['desc']) ? $param['desc']
                                               : null;
        $param['params'] = isset($param['params']) ? $param['params']
                                                   : null;

        $form->addVariable($param['label'], 'gateway_params[' . $id . ']', $param['type'], $param['required'], $param['readonly'], $param['desc'], $param['params']);
    }
}

if (!empty($send_params)) {
    $form->addVariable(_("Select which of the following parameters are set here and which are available for the user to set during the sending of a message."), 'send_params', 'header', false);
    foreach ($send_params as $id => $param) {
        $param['desc'] = isset($param['desc']) ? $param['desc'] : null;
        $param['params'] = isset($param['params']) ? $param['params'] : null;

        $form->addVariable($param['label'], 'gateway_sendparams[' . $id . ']', $param['type'], false, false, $param['desc'], $param['params']);
    }
}

/* Set up the gateway choice field. */
$vars->set('old_gateway_driver', $gateway);

if ($formname && !$changed_gateway) {
    $form->validate($vars);

    if ($form->isValid()) {
        $form->getInfo($vars, $info);

        /* Save the gateway. */
        $save = $storage->saveGateway($info);
        if (is_a($save, 'PEAR_Error')) {
            Horde::logMessage($save, __FILE__, __LINE__, PEAR_LOG_ERR);
            $notification->push(sprintf(_("Error saving gateway. %s."), $save->getMessage()), 'horde.error');
        } else {
            $notification->push(_("Gateway saved."), 'horde.success');
            $url = Horde::applicationUrl('gateways/index.php', true);
            header('Location: ' . $url);
            exit;
        }
    }
}

/* Render the form. */
require_once 'Horde/Form/Renderer.php';
$renderer = &new Horde_Form_Renderer();
$main = Util::bufferOutput(array($form, 'renderActive'), $renderer, $vars, 'edit.php', 'post');

/* Set up the template fields. */
$actions = array();
$swoosh_tpl->set('actions', $actions);
$swoosh_tpl->set('main', $main);
$swoosh_tpl->set('menu', Swoosh::getMenu('string'));
$swoosh_tpl->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

/* Render the page. */
require SWOOSH_TEMPLATES . '/common-header.inc';
echo $swoosh_tpl->fetch(SWOOSH_TEMPLATES . '/main/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
