<?php
/**
 * The Swoosh script to list the available gateways.
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: swoosh/gateways/index.php,v 1.17 2004/12/23 17:51:58 jan Exp $
 */

@define('SWOOSH_BASE', dirname(__FILE__) . '/..');
require_once SWOOSH_BASE . '/lib/base.php';

/* Only admin should be using this. */
if (!Auth::isAdmin()) {
    Horde::authenticationFailureRedirect();
}

/* Get the sorting. */
$sort_by = Swoosh::getSortBy('name');
$sort_dir = Swoosh::getSortDir('name');

$gateways_array = $storage->getGateways();
if (is_a($gateways_array, 'PEAR_Error')) {
    $notification->push(sprintf(_("Could not fetch list of gateways. %s"), $gateways_array->getMessage()), 'horde.error');
    $gateways_array = array();
} elseif (empty($gateways_array)) {
    $notification->push(_("No available gateways."), 'horde.warning');
}

if (count($gateways_array) > 0) {
    $gateway_drivers = Net_SMS::getDrivers();
    require_once 'Horde/Serialize.php';
}

$gateways = array();
$i = 0;
foreach ($gateways_array as $gateway) {
    /* View gateway url. */
    $url = Util::addParameter(Horde::applicationUrl('gateways/gateway.php'), 'gateway_id', $gateway['gateway_id']);
    $gateways[$i]['url'] = $url;

    $gateways[$i]['name'] = $gateway['gateway_name'];
    $gateways[$i]['driver'] = $gateway_drivers[$gateway['gateway_driver']];

    /* Get the gateway object, unserialize first the gateway params. */
    $gateway['gateway_params'] = Horde_Serialize::unserialize($gateway['gateway_params'], SERIALIZE_UTF7_BASIC);
    $gateway_driver = &Net_SMS::singleton($gateway['gateway_driver'], $gateway['gateway_params']);

    /* Work out the credit. */
    $credit = $gateway_driver->getBalance();
    if (is_a($credit, 'PEAR_Error')) {
        $gateways[$i]['credit'] = $credit->getMessage();
    } else {
        $gateways[$i]['credit'] = $credit;
    }

    /* Action links. */
    $gateways[$i]['actions'] = array();

    if (Auth::isAdmin()) {
        /* Edit gateway button. */
        $url = Util::addParameter(Horde::applicationUrl('gateways/edit.php'), 'gateway_id', $gateway['gateway_id']);
        $gateways[$i]['actions'][] = Horde::link($url, _("Edit gateway"), '', '', '', _("Edit gateway")) . Horde::img('edit.png', _("Edit gateway"), '', $registry->getImageDir('horde')) . '</a>';

        /* Delete gateway button. */
        $url = Util::addParameter(Horde::applicationUrl('gateways/delete.php'), 'gateway_id', $gateway['gateway_id']);
        $gateways[$i]['actions'][] = Horde::link($url, _("Delete gateway"), '', '', '', _("Delete gateway")) . Horde::img('delete.png', _("Delete gateway"), '', $registry->getImageDir('horde')) . '</a>';
    }
    $i++;
}

/* Sort the gateway list. */
require_once 'Horde/Array.php';
Horde_Array::arraySort($gateway_array, $sort_by, $sort_dir);

/* Set up actions. */
$actions = array();
$url = Horde::applicationUrl('gateways/edit.php');
$label = _("New Gateway");
$actions[] = array('url' => $url, 'link' => Horde::link($url, $label, 'smallheader', '', '', $label), 'label' => $label, 'icon' => Horde::img('new.png', $label));

$swoosh_tpl->set('actions', $actions);
$swoosh_tpl->set('gateways', $gateways, true);
$swoosh_tpl->set('listheaders', array(_("Name"), _("Driver"), _("Credits")));
$swoosh_tpl->set('menu', Swoosh::getMenu('string'));
$swoosh_tpl->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

require SWOOSH_TEMPLATES . '/common-header.inc';
echo $swoosh_tpl->fetch(SWOOSH_TEMPLATES . '/gateways/index.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
