<?php
/**
 * The Swoosh script to send an SMS message.
 *
 * Copyright 2003-2005 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: swoosh/send.php,v 1.33 2005/01/03 14:35:32 jan Exp $
 */

@define('SWOOSH_BASE', dirname(__FILE__));
require_once SWOOSH_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Variables.php';

/* Only authorised users should be using this. */
if (!Auth::getAuth()) {
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$vars = &Variables::getDefaultVariables();
$gateway_id = $vars->get('gateway_id');
$to = $vars->get('to');
$ambiguous_to = $vars->get('ambiguous_to');
$info = array();

/* Get list of set up gateways. */
$gateways = $storage->getGatewaySelect();
if (empty($gateways)) {
    $notification->push(_("No gateways available."), 'horde.error');
    header('Location: ' . Horde::applicationUrl('gateways/index.php', true));
    exit;
}
$num_gateways = count($gateways);

/* Set up the form object. */
$form = &Horde_Form::singleton('', $vars, _("Send Message"), 'send');

/* Set up the form. */
$form->setButtons(_("Send"), true);

/* Check how many gateways have been set up. */
if ($num_gateways > 1) {
    /* If more than one gateway offer the choice. */
    require_once 'Horde/Form/Action.php';
    $v = &$form->addVariable(_("Gateway"), 'gateway_id', 'enum', true, false, null, array($storage->getGatewaySelect(), true));
    $action = &Horde_Form_Action::factory('submit');
    $v->setOption('trackchange', true);
    $v->setAction($action);
    if ($gateway_id != $vars->get('__old_gateway_id')) {
        $notification->push(_("Changed gateway."), 'horde.message');
    }
} elseif ($num_gateways == 1) {
    /* Only one gateway, store the gateway id. */
    $gateway_id = key($gateways);
} else {
    $notification->push(_("No gateways set up."), 'horde.warning');
}

/* Selected a gateway so get parameters for this gateway. */
if ($gateway_id) {
    $gateway = $storage->getGateway($gateway_id);

    /* Get the gateway driver for this gateway id. */
    $gateway_driver = &Net_SMS::singleton($gateway['gateway_driver'], $gateway['gateway_params']);

    $info['send_params'] = $gateway_driver->getSendParams($gateway['gateway_sendparams']);
}

if (!empty($info['send_params'])) {
    foreach ($info['send_params'] as $id => $param) {
        if (!is_array($param)) {
            continue;
        }
        $param['required'] = isset($param['required']) ? $param['required']
                                                       : true;
        $param['readonly'] = isset($param['readonly']) ? $param['readonly']
                                                       : false;
        $param['desc'] = isset($param['desc']) ? $param['desc']
                                               : null;
        $param['params'] = isset($param['params']) ? $param['params']
                                                   : null;

        $form->addVariable($param['label'], 'send_params[' . $id . ']', $param['type'], $param['required'], $param['readonly'], $param['desc'], $param['params']);
    }
}

$field_name = _("Destination") . '<br /><span id="expandingto" style="color:red;visibility:hidden;">' . _("Expanding...") . '</span>';
$form->addVariable($field_name, 'to', 'longtext', (!$ambiguous_to), false, _("If you want to enter multiple recipients, separate them using commas or new lines."), array(2, 50));

if (!empty($to) || !empty($ambiguous_to)) {
    $expand = Swoosh::expandNumbers($to, $ambiguous_to);
    /* Check for ambiguous. */
    if (isset($expand['ambiguous'])) {
        require_once 'Horde/Array.php';
        /* Notify that some are ambiguous. */
        $notification->push(_("Fix ambiguous destinations."), 'horde.warning');
        foreach ($expand['ambiguous'] as $id => $choices) {
            $pos = strrpos($id, ':');
            $name = substr($id, 0, $pos);
            $key = substr($id, $pos + 1);
            $choices = Horde_Array::valuesToKeys($choices);
            $v = &$form->addVariable(sprintf(_("Select which '%s'"), $name), 'ambiguous_to[' . $key . ']', 'enum', false, false, null, array($choices, _("-- select below or leave blank for none --")));
            $v->setDefault(key($choices));
        }
    }
    /* Check for unmatched. */
    if (isset($expand['unmatched'])) {
        /* Notify that some have not been matched. */
        $notification->push(sprintf(_("Could not expand the following destinations: %s"), implode(', ', $expand['unmatched'])), 'horde.warning');
        /* Merge unmatched together with matched. */
        $expand['matched'] = $expand['matched'] + $expand['unmatched'];
        ksort($expand['matched']);
    }
    /* Handle any matched. */
    $expanded = '';
    if (!empty($expand['matched'])) {
        $expanded = implode("\r\n", $expand['matched']);
    }
    if ($to != $expanded) {
        /* Something has been expanded. */
        $vars->set('to', $expanded);
    }
    /* Only if there were ambiguous or unmatched entries re-present the
     * form for review. */
    if (isset($expand['ambiguous']) || isset($expand['unmatched'])) {
        $form->setSubmitted(false);
    }
}

$form->addVariable(_("Message"), 'text', 'countedtext', true, false, null, array(4, 50, 160));

if ($form->validate($vars)) {
    /* Make sure that the gateway id is there even in case of forms with no
     * gateway selection (single gateway setups). */
    $info['gateway_id'] = $gateway_id;
    $form->getInfo($vars, $info);

    /* For now do an explode to get an array. */
    $info['to'] = explode("\r\n", $info['to']);

    /* First save the message. */
    $info['id'] = $storage->saveMessage($info['gateway_id'], $info['text'], $info['send_params'], null);

    /* Do the send. */
    $sends = $gateway_driver->send($info);
    if (!is_a($sends, 'PEAR_Error')) {
        $notification->push(_("Message submitted."), 'horde.success');

        /* Store the sends. */
        foreach ($sends as $send) {
            $storage->saveSend($send['message_id'], $send['remote_id'], $send['recipient'], $send['error']);
        }

        $url = Horde::applicationUrl('send.php', true);
        header('Location: ' . $url);
        exit;
    }

    Horde::logMessage($sends, __FILE__, __LINE__, PEAR_LOG_ERR);
    $notification->push(sprintf(_("Error submitting message. %s"), $sends->getMessage()), 'horde.error');
}

/* Render the form. */
require_once 'Horde/Form/Renderer.php';
$renderer = &new Horde_Form_Renderer();
$inputform = Util::bufferOutput(array($form, 'renderActive'), $renderer, $vars, 'send.php', 'post');

/* Create the actions. */
$actions = array();

Horde::addScriptFile('expand.js');
$label = _("Expand Names");
$actions[] = array('url' => '#', 'link' => Horde::link('#', $label, '', '', "expandField(document.getElementById('to')); return false;", $label), 'label' => $label);

$autoexpand = '';
if ($prefs->getValue('auto_expand')) {
    $autoexpand = '<iframe id="autoexpand" name="autoexpand" style="width:0px;height:0px;border-width:0px" src="' . Horde::applicationUrl('expand.php') . '"></iframe>';
}

/* Set up the template fields. */
$swoosh_tpl->set('actions', $actions);
$swoosh_tpl->set('inputform', $inputform, true);
$swoosh_tpl->set('autoexpand', $autoexpand, true);
$swoosh_tpl->set('menu', Swoosh::getMenu('string'));
$swoosh_tpl->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

/* Render the page. */
require SWOOSH_TEMPLATES . '/common-header.inc';
echo $swoosh_tpl->fetch(SWOOSH_TEMPLATES . '/send/send.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
